@@ -5,12 +5,11 @@
     license: GNU Lesser General Public License v3.0 (see LICENSE)
 '''
 
-from csb43.utils import check_strict, raiseCsb43Exception, DECIMAL
+from csb43.utils import check_strict, raiseCsb43Exception, DECIMAL, currencyISO, currencyISOByLetter, isCurrency
 import csb43.utils.messages as msg
 from csb43.i18n import tr as _
 from transaction import Transaction
 from record import Record
-import pycountry
 
 import re
 
@@ -136,7 +135,7 @@ class Account(Record):
     def _get_external_currency_code(self):
         if self.__currencyCode is None:
             return None
-        return pycountry.currencies.get(numeric=self.__currencyCode)
+        return currencyISO(self.__currencyCode)
 
     @check_strict(r'^[ \d]{3}$')
     def _set_currency_code(self, value, strict=True):
@@ -144,7 +143,7 @@ class Account(Record):
 
     def _set_external_currency_code(self, value):
         try:
-            if isinstance(value, pycountry.db.Data):
+            if isCurrency(value):
                 self._set_currency_code(str(value.numeric))
             else:
                 import numbers
@@ -154,9 +153,9 @@ class Account(Record):
                     val = str(value)
                 obj = None
                 if _CUR_NUM.match(val):
-                    obj = pycountry.currencies.get(numeric=val)
+                    obj = currencyISO(val)
                 elif _CUR_LET.match(val):
-                    obj = pycountry.currencies.get(letter=val.upper())
+                    obj = currencyISOByLetter(val.upper())
                 else:
                     raiseCsb43Exception(msg.CURRENCY_EXPECTED(val), strict=True)
                 if obj:
@@ -784,7 +783,7 @@ class ClosingAccount(Record):
     def _get_external_currency_code(self):
         if self.__currencyCode is None:
             return None
-        return pycountry.currencies.get(numeric=self.__currencyCode)
+        return currencyISO(self.__currencyCode)
 
     def _get_padding(self):
         return self.__padding
@@ -832,7 +831,7 @@ class ClosingAccount(Record):
 
     def _set_external_currency_code(self, value):
         try:
-            if isinstance(value, pycountry.db.Data):
+            if isCurrency(value):
                 self._set_currency_code(str(value.numeric))
             else:
                 import numbers
@@ -842,9 +841,9 @@ class ClosingAccount(Record):
                     val = str(value)
                 obj = None
                 if _CUR_NUM.match(val):
-                    obj = pycountry.currencies.get(numeric=val)
+                    obj = currencyISO(val)
                 elif _CUR_LET.match(val):
-                    obj = pycountry.currencies.get(letter=val.upper())
+                    obj = currencyISOByLetter(val.upper())
                 else:
                     raiseCsb43Exception(msg.CURRENCY_EXPECTED(val), strict=True)
                 if obj:
