@@ -80,22 +80,20 @@ class OfxObject(object):
 
     def __init__(self, tagName):
         '''
-        Args:
-            tagName (str) -- name for the XML tag
+        :param tagName: name for the XML tag
+        :type tagName: :class:`str`
         '''
         self._tagName = tagName
 
     def _get_content(self):
         '''
-        Return:
-            the xml representation of this object
+        :rtype: the xml representation of this object
         '''
         return ""
 
     def get_tag_name(self):
         '''
-        Return:
-            the XML tag name
+        :rtype: the XML tag name
         '''
         return self._tagName
 
@@ -103,12 +101,15 @@ class OfxObject(object):
         '''
         Set a XML tag name for this object
 
-        Args:
-            tagName (str) -- name for the XML tag
+        :param name: name for the XML tag
+        :type name: :class:`str`
         '''
         self._tagName = name
 
     def __str__(self):
+        '''
+        :rtype: XML representation of the object
+        '''
         # return getXMLTag(self._tagName, self._get_content())
         return self._get_content()
 
@@ -116,12 +117,19 @@ class OfxObject(object):
 class File(OfxObject):
     '''
     An OFX file
+
+    >>> from csb43.ofx import File
+    >>> f = File()
+    >>> print f
+    <?xml version="1.0" encoding="ASCII"?>
+    <?OFX OFXHEADER="200" VERSION="211" SECURITY="NONE"
+    OLDFILEUID="NONE" NEWFILEUID="NONE"?><OFX><BANKMSGSRSV1></BANKMSGSRSV1></OFX>
     '''
 
     def __init__(self, tagName="ofx"):
         '''
-        Args:
-            tagName (str) -- see *OfxObject*
+        :param tagName: tag's name to be used for this object
+        :type tagName: :class:`str`
         '''
         super(File, self).__init__(tagName)
 
@@ -137,8 +145,7 @@ class File(OfxObject):
 
     def get_responses(self):
         '''
-        Return:
-            list of responses
+        :rtype: :class:`list` of :class:`Response`
         '''
         return self.__responses
 
@@ -153,15 +160,15 @@ class File(OfxObject):
         '''
         Add a response to the file
 
-        Args:
-            value (Response) -- a response
+        :param value: a response object to include in this object
+        :type value: :class:`Response`
         '''
         self.__responses.append(value)
 
     def _get_content(self):
         header = '<?xml version="1.0" encoding="ASCII"?>\n'
         header += """<?OFX OFXHEADER="200" VERSION="211" SECURITY="NONE"
-                    OLDFILEUID="NONE" NEWFILEUID="NONE"?>"""
+ OLDFILEUID="NONE" NEWFILEUID="NONE"?>"""
         content = ""
         for r in self.__responses:
             aux = getXMLTag("trnuid", 0)
@@ -177,8 +184,8 @@ class Response(OfxObject):
 
     def __init__(self, tagName="stmtrs"):
         '''
-        Args:
-            tagName (str) -- see *OfxObject*
+        :param tagName: name for the XML tag
+        :type tagName: :class:`str`
         '''
         super(Response, self).__init__(tagName)
 
@@ -192,85 +199,78 @@ class Response(OfxObject):
 
     def get_currency(self):
         '''
-        Return:
-            (pycountry.Curency) -- Default currency for the statement
+        :rtype: :class:`pycountry.dbCurrency` -- Default currency for the statement
         '''
         return self.__currency
 
     def get_bank_account_from(self):
         '''
-        Return:
-            (BankAccount) -- Account-from aggregate
+        :rtype: :class:`BankAccount` -- Account-from aggregate
         '''
         return self.__accountFrom
 
     def get_transaction_list(self):
         '''
-        Return:
-            (TransactionList) -- Statement-transaction-data aggregate
+        :rtype: :class:`TransactionList` -- Statement-transaction-data aggregate
         '''
         return self.__transactionList
 
     def get_ledger_balance(self):
         '''
-        Return:
-            (Balance) -- the ledger balance aggregate
+        :rtype: :class:`Balance` -- the ledger balance aggregate
         '''
         return self.__ledgerBalance
 
     def get_available_balance(self):
         '''
-        Return:
-            (Balance) -- the available balance aggregate
+        :rtype: `Balance` -- the available balance aggregate
         '''
         return self.__availableBalance
 
     def get_balances(self):
         '''
-        Return:
-            list of miscellaneous other balances
+        :rtype: :class:`list` of miscellaneous other :class:`Balance` s
         '''
         return self.__balances
 
     def get_mktginfo(self):
         '''
-        Return:
-            marketing info
+        :rtype: marketing info
         '''
         return self.__mktginfo
 
     def set_currency(self, value):
         '''
-        Args:
-            value (pycountry.Currency)
+        :param value: currency
+        :type value: :class:`pycountry.db.Currency`
         '''
         self.__currency = value
 
     def set_bank_account_from(self, value):
         '''
-        Args:
-            value (BankAccount)
+        :param value: value
+        :type value: :class:`BankAccount`
         '''
         self.__accountFrom = value
 
     def set_transaction_list(self, value):
         '''
-        Args:
-            value (TransactionList)
+        :param value: transactions list
+        :type value: :class:`TransactionList`
         '''
         self.__transactionList = value
 
     def set_ledger_balance(self, value):
         '''
-        Args:
-            value (Balance)
+        :param value: ledger balance
+        :type value: :class:`Balance`
         '''
         self.__ledgerBalance = value
 
     def set_available_balance(self, value):
         '''
-        Args:
-            value (Balance)
+        :param value: available balance
+        :type  value: :class:`Balance`
         '''
         self.__availableBalance = value
 
@@ -278,15 +278,14 @@ class Response(OfxObject):
         '''
         Add a complementary balance
 
-        Args:
-            value (Balance)
+        :param value: a complementary balance
+        :type  value: :class:`Balance`
         '''
         self.__balances.append(value)
 
     def set_mktginfo(self, value):
         '''
-        Args:
-            value -- marketing info
+        :param value: marketing info
         '''
         self.__mktginfo = value
 
@@ -323,36 +322,33 @@ class TransactionList(OfxObject):
 
     def get_date_start(self):
         '''
-        Return:
-            (datetime) -- date of the first transaction
+        :rtype: :class:`datetime.datetime` -- date of the first transaction
         '''
         return self.__dateStart
 
     def get_date_end(self):
         '''
-        Return:
-            (datetime) -- date of the first transaction
+        :rtype: :class:`datetime.datetime` -- date of the first transaction
         '''
         return self.__dateEnd
 
     def get_list(self):
         '''
-        Return:
-            list of transactions
+        :rtype: :class:`list` of :class:`Transaction`
         '''
         return self.__list
 
     def set_date_start(self, value):
         '''
-        Args:
-            value (datetime)
+        :param value: date of start
+        :type  value: :class:`datetime.datetime`
         '''
         self.__dateStart = value
 
     def set_date_end(self, value):
         '''
-        Args:
-            value (datetime)
+        :param value: date of end
+        :type  value: :class:`datetime.datetime`
         '''
         self.__dateEnd = value
 
@@ -360,8 +356,8 @@ class TransactionList(OfxObject):
         '''
         Add a new transaction to the list
 
-        Args:
-            value (Transaction)
+        :param value: a transaction
+        :type  value: :class:`Transaction`
         '''
         self.__list.append(value)
 
@@ -379,6 +375,7 @@ class Transaction(OfxObject):
     A OFX transaction
     '''
 
+    #: type of transaction
     TYPE = ["CREDIT",  # 0
             "DEBIT",  # 1
             "INT",  # 2
@@ -399,8 +396,8 @@ class Transaction(OfxObject):
 
     def __init__(self, tagName="stmttrn"):
         '''
-        Args:
-            tagName (str) -- see *OfxObject*
+        :param tagName: see :class:`OfxObject`
+        :type  tagName: :class:`str`
         '''
         super(Transaction, self).__init__(tagName)
 
@@ -430,38 +427,43 @@ class Transaction(OfxObject):
 
     def get_name(self):
         '''
-        Return:
-            (str) -- name of payee or description of transaction
+        :rtype: :class:`str` -- name of payee or description of transaction
         '''
         return self.__name
 
     def get_extended_name(self):
         '''
-        Return:
-            (str) -- extended name of payee or description of transaction
+        :rtype: :class:`str` -- extended name of payee or description of transaction
         '''
         return self.__extendedName
 
     def set_name(self, value):
+        '''
+        :param value: name of payee or description of transaction
+        '''
         self.__name = value
 
     def set_extended_name(self, value):
+        '''
+        :param value: extended name of payee or description of transaction
+        '''
         self.__extendedName = value
 
     def get_ref_num(self):
         '''
-        Return:
-            (str) -- reference number that uniquely indentifies the transaction.
+        :rtype: :class:`str` -- reference number that uniquely indentifies the transaction.
         '''
         return self.__refNum
 
     def set_ref_num(self, value):
+        '''
+        :param value: reference number that uniquely indentifies the transaction.
+        '''
         self.__refNum = value
 
     def get_type(self):
         '''
-        Return:
-            (str) -- transaction type. See *TYPE*. Default ('OTHER')
+        :rtype: :class:`str` -- transaction type. See :class:`TYPE`. Default ('OTHER')
         '''
         if self.__type is None:
             return Transaction.TYPE[-1]
@@ -470,105 +472,109 @@ class Transaction(OfxObject):
 
     def get_date_posted(self):
         '''
-        Return:
-            (datetime) -- date transaction was posted to account
+        :rtype: :class:`datetime.datetime` -- date transaction was posted to account
         '''
         return self.__datePosted
 
     def get_date_initiated(self):
         '''
-        Return:
-            (datetime) -- date user initiated transaction
+        :rtype: :class:`datetime.datetime` -- date user initiated transaction
         '''
         return self.__dateInitiated
 
     def get_date_available(self):
         '''
-        Return:
-            (datetime) -- date funds are available
+        :rtype: :class:`datetime.datetime` -- date funds are available
         '''
         return self.__dateAvailable
 
     def get_amount(self):
         '''
-        Return:
-            (number) -- amount of transaction
+        :rtype: number -- amount of transaction
         '''
         return self.__amount
 
     def get_transaction_id(self):
         '''
-        Return:
-            (str) -- transaction ID issued by financial institution
+        :rtype: :class:`str` -- transaction ID issued by financial institution
         '''
         return self.__transactionId
 
     def get_correct_fit_id(self):
+        '''
+        correct fit id
+        '''
         return self.__correctFitId
 
     def get_correct_action(self):
+        '''
+        correct action
+        '''
         return self.__correctAction
 
     def get_server_tid(self):
+        '''
+        server transaction id
+        '''
         return self.__serverTid
 
     def get_check_num(self):
         '''
-        Return:
-            (str) -- check (or other reference) number
+        :rtype: :class:`str` -- check (or other reference) number
         '''
         return self.__checkNum
 
     def get_standard_industrial_code(self):
+        '''
+        standard industrial code
+        '''
         return self.__standardIndustrialCode
 
     def get_payee(self):
         '''
-        Return:
-            (Payee)
+        :rtype: :class:`Payee`
         '''
         return self.__payee
 
     def get_payeeid(self):
         '''
-        Return:
-            (str) -- payee identifier
+        :rtype: :class:`str` -- payee identifier
         '''
         return self.__payeeid
 
     def get_bank_account_to(self):
         '''
-        Return:
-            (BankAccount) -- account the transaction is transferring to
+        :rtype: :class:`BankAccount` -- account the transaction is transferring to
         '''
         return self.__bankAccountTo
 
     def get_cc_account_to(self):
+        '''
+        cc account to
+        '''
         return self.__ccAccountTo
 
     def get_memo(self):
         '''
-        Return:
-            (str) -- extra information
+        :rtype: :class:`str` -- extra information
         '''
         return self.__memo
 
     def get_image_data(self):
+        '''
+        image data
+        '''
         return self.__imageData
 
     def get_currency(self):
         '''
-        Return:
-            (pycountry.Currency) -- currency of the transaction,
-            if different from the one in *Account*
+        :rtype: :class:`pycountry.db.Currency` -- currency of the transaction, if different from the one in :class:`BankAccount`
         '''
         return self.__currency
 
     def get_origin_currency(self):
         '''
-        Return:
-            (pycountry.Currency) -- currency of the transaction, if different
-            from the one in *Account*
+        :rtype: :class:`pycountry.db.Currency` -- currency of the transaction, if different from the one in :class:`BankAccount`
         '''
         return self.__originCurrency
 
@@ -669,6 +675,7 @@ class BankAccount(OfxObject):
     A bank account
     '''
 
+    #: account type
     TYPE = ["CHECKING", "SAVINGS", "MONEYMRKT", "CREDITLINE"]
 
     def __init__(self, tagName="bankaccfrom"):
@@ -682,8 +689,7 @@ class BankAccount(OfxObject):
 
     def get_type(self):
         '''
-        Return:
-            (str) -- type of account. See *TYPE* (default 'SAVINGS')
+        :rtype: :class:`str` -- type of account. See :class:`TYPE` (default *'SAVINGS'*)
         '''
         if self.__type is None:
             return BankAccount.TYPE[1]
@@ -692,45 +698,57 @@ class BankAccount(OfxObject):
 
     def get_key(self):
         '''
-        Return:
-            (str) -- checksum (Spain: digitos de control)
+        :rtype: :class:`str` -- checksum (Spain: digitos de control)
         '''
         return self.__key
 
     def set_type(self, value):
+        '''
+        :param value: type of account
+        :type  value: :class:`str`
+        '''
         self.__type = value
 
     def set_key(self, value):
+        '''
+        :param value: checksum
+        '''
         self.__key = value
 
     def get_bank(self):
         '''
-        Return:
-            (str) -- bank identifier (Spain: banco, entidad)
+        :rtype: :class:`str` -- bank identifier (Spain: banco, entidad)
         '''
         return self.__bankId
 
     def get_branch(self):
         '''
-        Return:
-            (str) -- branch identifier (Spain: sucursal, oficina)
+        :rtype: :class:`str` -- branch identifier (Spain: sucursal, oficina)
         '''
         return self.__branchId
 
     def get_id(self):
         '''
-        Return:
-            (str) -- account identifier
+        :rtype: :class:`str` -- account identifier
         '''
         return self.__id
 
     def set_bank(self, value):
+        '''
+        :param value: bank identifier
+        '''
         self.__bankId = value
 
     def set_branch(self, value):
+        '''
+        :param branch: branch identifier
+        '''
         self.__branchId = value
 
     def set_id(self, value):
+        '''
+        :param value: account id
+        '''
         self.__id = value
 
     def _get_content(self):
@@ -797,22 +815,27 @@ class Balance(OfxObject):
 
     def get_amount(self):
         '''
-        Return:
-            the amount of the balance
+        :rtype: the amount of the balance
         '''
         return self.__amount
 
     def get_date(self):
         '''
-        Return:
-            (datetime) -- date of the balance
+        :rtype: :class:`datetime` -- date of the balance
         '''
         return self.__date
 
     def set_amount(self, value):
+        '''
+        :param value: amount
+        '''
         self.__amount = value
 
     def set_date(self, value):
+        '''
+        :param value: a date object
+        :type  value: :class:`datetime.datetime`
+        '''
         self.__date = value
 
     def _get_content(self):
@@ -820,3 +843,4 @@ class Balance(OfxObject):
                                                         self.__amount),
                                        date=getXMLTag("datasof",
                                                       strDate(self.__date)))
+
